@@ -3,6 +3,7 @@ import requests
 from .automations import Automations
 from .contacts import Contacts
 from .deals import Deals
+from .deepdataintegrations import DeepDataIntegrations
 from .lists import Lists
 from .notes import Notes
 from .tasks import Tasks
@@ -10,6 +11,8 @@ from .users import Users
 from .webhooks import Webhooks
 from .messages import Messages
 from .tags import Tags
+from .emailActivities import EmailActivities
+from .dealActivities import DealActivities
 
 
 class Client(object):
@@ -28,7 +31,10 @@ class Client(object):
         self.users = Users(self)
         self.webhooks = Webhooks(self)
         self.messages = Messages(self)
+        self.deepdataintegrations = DeepDataIntegrations(self)
         self.tags = Tags(self)
+        self.emailActivities = EmailActivities(self)
+        self.dealActivities = DealActivities(self)
 
     def _get(self, endpoint, **kwargs):
         return self._request('GET', endpoint, **kwargs)
